cumulusci.salesforce_api package
================================

Submodules
----------

cumulusci.salesforce_api.exceptions module
------------------------------------------

.. automodule:: cumulusci.salesforce_api.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.salesforce_api.metadata module
----------------------------------------

.. automodule:: cumulusci.salesforce_api.metadata
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.salesforce_api.package_zip module
-------------------------------------------

.. automodule:: cumulusci.salesforce_api.package_zip
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.salesforce_api.soap_envelopes module
----------------------------------------------

.. automodule:: cumulusci.salesforce_api.soap_envelopes
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.salesforce_api
    :members:
    :undoc-members:
    :show-inheritance:
